* aix5ppc-core.c: Fix comment typos.
authorKazu Hirata <kazu@codesourcery.com>
Mon, 24 Nov 2003 18:06:40 +0000 (18:06 +0000)
committerKazu Hirata <kazu@codesourcery.com>
Mon, 24 Nov 2003 18:06:40 +0000 (18:06 +0000)
* aout-arm.c: Likewise.
* aout-ns32k.c: Likewise.
* aoutx.h: Likewise.
* archures.c: Likewise.
* bfd-in.h: Likewise.
* bfd.c: Likewise.
* bfdio.c: Likewise.
* coff-arm.c: Likewise.
* coff-h8300.c: Likewise.
* coff-i860.c: Likewise.
* coff-m88k.c: Likewise.
* coff-mcore.c: Likewise.
* coff-ppc.c: Likewise.
* coff-rs6000.c: Likewise.
* coff-z8k.c: Likewise.
* coff64-rs6000.c: Likewise.
* coffcode.h: Likewise.
* cofflink.c: Likewise.
* cpu-alpha.c: Likewise.
* cpu-arm.c: Likewise.
* cpu-ns32k.c: Likewise.
* dwarf2.c: Likewise.
* bfd-in2.h: Regenerate.

24 files changed:
bfd/aix5ppc-core.c
bfd/aout-arm.c
bfd/aout-ns32k.c
bfd/aoutx.h
bfd/archures.c
bfd/bfd-in.h
bfd/bfd-in2.h
bfd/bfd.c
bfd/bfdio.c
bfd/coff-arm.c
bfd/coff-h8300.c
bfd/coff-i860.c
bfd/coff-m88k.c
bfd/coff-mcore.c
bfd/coff-ppc.c
bfd/coff-rs6000.c
bfd/coff-z8k.c
bfd/coff64-rs6000.c
bfd/coffcode.h
bfd/cofflink.c
bfd/cpu-alpha.c
bfd/cpu-arm.c
bfd/cpu-ns32k.c
bfd/dwarf2.c

index b0a9c5e715efab75b49e9684177cad439d998570..03510765e18653d3f22857808cf3c09fe05d81f2 100644 (file)
@@ -102,7 +102,7 @@ xcoff64_core_p (abfd)
       || (! (core.c_flag & LE_VALID)))
     goto xcoff64_core_p_error;
 
-  /* Check for trucated stack or general truncating.  */
+  /* Check for truncated stack or general truncating.  */
   if ((! (core.c_flag & USTACK_VALID))
       || (core.c_flag & CORE_TRUNC))
     {
index 34a235a806a8a6873b419474773cc07f66a275c3..38ecfab9d418b85171ebc05432f6822626cf60a8 100644 (file)
@@ -22,7 +22,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 #include "bfd.h"
 #include "sysdep.h"
 
-/* Avoid multiple defininitions from aoutx if supporting standarad a.out
+/* Avoid multiple definitions from aoutx if supporting standard a.out
    as well as our own.  */
 /* Do not "beautify" the CONCAT* macro args.  Traditional C will not
    remove whitespace added here, and thus will fail to concatenate
index 8092705ba113c48757e8033486396c418a14e03a..1ac8d710a8ea32b073e6f0abd1137bf2bdd3b285 100644 (file)
@@ -70,7 +70,7 @@ MY(put_reloc) PARAMS ((bfd *, int, int, bfd_vma, reloc_howto_type *,
    data. Of these, only the last fits into the standard relocation
    scheme.  Immediate operands are stored huffman encoded and
    immediate operands are stored big endian (where as the natural byte
-   order is little endian for this achitecture).
+   order is little endian for this architecture).
 
    Note that the ns32k displacement storage method is orthogonal to
    whether the relocation is pc relative or not. The "displacement"
index 6c20bd010af8182a61340b19f3fc62a25f8e4846..3282f87dfe238382fc30f32020082b58a5689b27 100644 (file)
@@ -3254,7 +3254,7 @@ aout_link_check_ar_symbols (abfd, info, pneeded)
             and this object file from the archive includes:
                 int a = 5;
             In such a case, whether to include this object is target
-             dependant for backward compatability.
+             dependant for backward compatibility.
 
             FIXME: The SunOS 4.1.3 linker will pull in the archive
             element if the symbol is defined in the .data section,
index 064fa55756ad7df310bc4acea837dc284d1e346e..18994a5755e6d3a8977824327e392534154e0896 100644 (file)
@@ -865,7 +865,7 @@ bfd_default_scan (const bfd_arch_info_type *info, const char *string)
     }
 
   /* Given that PRINTABLE_NAME has the form: <arch> ":" <mach>; Do not
-     attempt to match just <mach>, it could be ambigious.  This test
+     attempt to match just <mach>, it could be ambiguous.  This test
      is left until later.  */
 
   /* NOTE: The below is retained for compatibility only.  Please do
@@ -1046,7 +1046,7 @@ SYNOPSIS
          (enum bfd_architecture arch, unsigned long machine);
 
 DESCRIPTION
-       Look for the architecure info structure which matches the
+       Look for the architecture info structure which matches the
        arguments @var{arch} and @var{machine}. A machine of 0 matches the
        machine/architecture structure which marks itself as the
        default.
index 1a67d08ad2be2bb7ce8117e900cc1004a9fcb491..ccfef1e9370c5e8491bd38a1d02509e19b3f7d6e 100644 (file)
@@ -185,7 +185,7 @@ typedef unsigned char bfd_byte;
 typedef enum bfd_format
 {
   bfd_unknown = 0,     /* File format is unknown.  */
-  bfd_object,          /* Linker/assember/compiler output.  */
+  bfd_object,          /* Linker/assembler/compiler output.  */
   bfd_archive,         /* Object archive file.  */
   bfd_core,            /* Core dump.  */
   bfd_type_end         /* Marks the end; don't use it!  */
index 5c17a7a4d75f547826f100cbc9aea66da639b92b..d7c8a8124588ed453b4c43b9bd0ddaf2faaf39a7 100644 (file)
@@ -192,7 +192,7 @@ typedef unsigned char bfd_byte;
 typedef enum bfd_format
 {
   bfd_unknown = 0,     /* File format is unknown.  */
-  bfd_object,          /* Linker/assember/compiler output.  */
+  bfd_object,          /* Linker/assembler/compiler output.  */
   bfd_archive,         /* Object archive file.  */
   bfd_core,            /* Core dump.  */
   bfd_type_end         /* Marks the end; don't use it!  */
index ab2db6ab6e084600fda2f2d5db2fda0c2fc552dd..d37a48bc23bd2de04a1c3d84a9aeda3ed15ebbaf 100644 (file)
--- a/bfd/bfd.c
+++ b/bfd/bfd.c
@@ -396,7 +396,7 @@ SUBSECTION
 
        Some BFD functions want to print messages describing the
        problem.  They call a BFD error handler function.  This
-       function may be overriden by the program.
+       function may be overridden by the program.
 
        The BFD error handler acts like printf.
 
index f99fddd482981208350226df59056caf818c17ca..b196a52fdf1c7476947dfd7228bcec43c45e35e3 100644 (file)
@@ -395,7 +395,7 @@ DESCRIPTION
        error when it tries to read the table, or a "virtual memory
        exhausted" error when it tries to allocate 15 bazillon bytes
        of space for the 15 bazillon byte table it is about to read.
-       This function at least allows us to answer the quesion, "is the
+       This function at least allows us to answer the question, "is the
        size reasonable?".
 */
 
index 3655a30903b46d1304594071bb56be678bc2ef43..1d605678c143edbaf84a8a5abaf4bee6b295fb7f 100644 (file)
@@ -921,13 +921,13 @@ struct coff_arm_link_hash_table
     /* The original coff_link_hash_table structure.  MUST be first field.  */
     struct coff_link_hash_table        root;
 
-    /* The size in bytes of the section containg the Thumb-to-ARM glue.  */
+    /* The size in bytes of the section containing the Thumb-to-ARM glue.  */
     bfd_size_type              thumb_glue_size;
 
-    /* The size in bytes of the section containg the ARM-to-Thumb glue.  */
+    /* The size in bytes of the section containing the ARM-to-Thumb glue.  */
     bfd_size_type              arm_glue_size;
 
-    /* An arbitary input BFD chosen to hold the glue sections.  */
+    /* An arbitrary input BFD chosen to hold the glue sections.  */
     bfd *                      bfd_of_glue_owner;
 
     /* Support interworking with old, non-interworking aware ARM code.  */
@@ -991,7 +991,7 @@ arm_emit_base_file_entry (info, output_bfd, input_section, reloc_offset)
    instruction.
 
    It takes two thumb instructions to encode the target address. Each has
-   11 bits to invest. The upper 11 bits are stored in one (identifed by
+   11 bits to invest. The upper 11 bits are stored in one (identified by
    H-0.. see below), the lower 11 bits are stored in the other (identified
    by H-1).
 
@@ -1299,7 +1299,7 @@ coff_arm_relocate_section (output_bfd, info, input_bfd, input_section,
          /* FIXME - it is not clear which targets need this next test
             and which do not.  It is known that it is needed for the
             VxWorks and EPOC-PE targets, but it is also known that it
-            was supressed for other ARM targets.  This ought to be
+            was suppressed for other ARM targets.  This ought to be
             sorted out one day.  */
 #ifdef ARM_COFF_BUGFIX
          /* We must not ignore the symbol value.  If the symbol is
@@ -2228,7 +2228,7 @@ coff_arm_adjust_symndx (obfd, info, ibfd, sec, irel, adjustedp)
 /* Called when merging the private data areas of two BFDs.
    This is important as it allows us to detect if we are
    attempting to merge binaries compiled for different ARM
-   targets, eg different CPUs or differents APCS's.     */
+   targets, eg different CPUs or different APCS's.     */
 
 static bfd_boolean
 coff_arm_merge_private_bfd_data (ibfd, obfd)
@@ -2361,7 +2361,7 @@ coff_arm_print_private_bfd_data (abfd, ptr)
 
   if (APCS_SET (abfd))
     {
-      /* xgettext: APCS is ARM Prodecure Call Standard, it should not be translated.  */
+      /* xgettext: APCS is ARM Procedure Call Standard, it should not be translated.  */
       fprintf (file, " [APCS-%d]", APCS_26_FLAG (abfd) ? 26 : 32);
 
       if (APCS_FLOAT_FLAG (abfd))
index 5cb327a8f972c920b1fd8297edb7816b37364f70..e9d19643e43f259a31ea7d414f9389434e99e558 100644 (file)
@@ -775,7 +775,7 @@ h8300_reloc16_extra_cases (bfd *abfd, struct bfd_link_info *link_info,
       src_address += 4;
       break;
 
-    /* A 16bit abolute relocation that was formerlly a 24/32bit
+    /* A 16bit absolute relocation that was formerly a 24/32bit
        absolute relocation.  */
     case R_MOVL2:
       value = bfd_coff_reloc16_get_value (reloc, link_info, input_section);
index 74b599c91da8a7e3248f493bc3294e4bee840463..db77a2cda49766e7b401c9a9d31bf5d875068ee6 100644 (file)
@@ -524,7 +524,7 @@ coff_i860_rtype_to_howto (bfd *abfd ATTRIBUTE_UNUSED,
       BFD_ASSERT (h != NULL);
 
       /* I think we *do* want to bypass this.  If we don't, I have seen some data
-        parameters get the wrong relcation address.  If I link two versions
+        parameters get the wrong relocation address.  If I link two versions
         with and without this section bypassed and then do a binary comparison,
         the addresses which are different can be looked up in the map.  The
         case in which this section has been bypassed has addresses which correspond
index a8b2c55e319b252c91a19068e459284a3c935cbb..bef0eabef33c481478ab47895b38fb13981969b0 100644 (file)
@@ -1,4 +1,4 @@
-/* BFD back-end for Motorola 88000 COFF "Binary Compatability Standard" files.
+/* BFD back-end for Motorola 88000 COFF "Binary Compatibility Standard" files.
    Copyright 1990, 1991, 1992, 1993, 1994, 1995, 1997, 1998, 1999, 2000,
    2001, 2002, 2003
    Free Software Foundation, Inc.
@@ -85,7 +85,7 @@ m88k_special_reloc (abfd, reloc_entry, symbol, data,
          asection *reloc_target_output_section;
          long relocation = 0;
 
-         /* Work out which section the relocation is targetted at and the
+         /* Work out which section the relocation is targeted at and the
             initial relocation command value.  */
 
          /* Get symbol value.  (Common symbols are special.)  */
index c4b073592ed349a72d7286afe7a8068f5554e0ec..25569e3f24902c15091b4bff7cb2901ae180a478 100644 (file)
@@ -587,7 +587,7 @@ coff_mcore_relocate_section (output_bfd, info, input_bfd, input_section,
 
 #include "coffcode.h"
 \f
-/* Forward declaration to initialise alterbative_target field.  */
+/* Forward declaration to initialise alternative_target field.  */
 extern const bfd_target TARGET_LITTLE_SYM;
 
 /* The transfer vectors that lead the outside world to all of the above.  */
index cf54942314beb3931d58f1c5229fb48bc402f8ae..c1c2c32a178b36378e247de767ad7ce1689fadf4 100644 (file)
@@ -929,7 +929,7 @@ ppc_record_toc_entry(abfd, info, sec, sym, toc_kind)
          local_syms[sym] = global_toc_size;
          global_toc_size += 4;
 
-         /* The size must fit in a 16bit displacment.  */
+         /* The size must fit in a 16-bit displacement.  */
          if (global_toc_size > 65535)
            {
              (*_bfd_error_handler) (_("TOC overflow"));
@@ -949,7 +949,7 @@ ppc_record_toc_entry(abfd, info, sec, sym, toc_kind)
          h->toc_offset = global_toc_size;
          global_toc_size += 4;
 
-         /* The size must fit in a 16bit displacment.  */
+         /* The size must fit in a 16-bit displacement.  */
          if (global_toc_size >= 65535)
            {
              (*_bfd_error_handler) (_("TOC overflow"));
@@ -1274,7 +1274,7 @@ coff_ppc_relocate_section (output_bfd, info, input_bfd, input_section,
                    our_toc_offset = val - (toc_section->output_section->vma
                                            + toc_section->output_offset);
 
-                   /* The size must still fit in a 16bit displacment.  */
+                   /* The size must still fit in a 16-bit displacement.  */
                    if ((bfd_vma) our_toc_offset >= 65535)
                      {
                        (*_bfd_error_handler)
@@ -1931,7 +1931,7 @@ ppc_imglue_reloc (abfd, reloc_entry, symbol, data,
 #define MAX_RELOC_INDEX  \
       (sizeof (ppc_coff_howto_table) / sizeof (ppc_coff_howto_table[0]) - 1)
 
-/* FIXME: There is a possiblity that when we read in a reloc from a file,
+/* FIXME: There is a possibility that when we read in a reloc from a file,
           that there are some bits encoded in the upper portion of the
          type field. Not yet implemented.  */
 static void ppc_coff_rtype2howto PARAMS ((arelent *, struct internal_reloc *));
index 0b73bd54a8fc2e937806a7673c1d111335ade2a1..a7cf1ab139da754a44c245f1b00106c304ec7a78 100644 (file)
@@ -1006,7 +1006,7 @@ xcoff_rtype2howto (relent, internal)
   /* Default howto layout works most of the time */
   relent->howto = &xcoff_howto_table[internal->r_type];
 
-  /* Special case some 16 bit reoloc */
+  /* Special case some 16 bit reloc */
   if (15 == (internal->r_size & 0x1f))
     {
       if (R_BA == internal->r_type)
index 15c7f9d2186133bf137b9969832d44566a48b858..db55cc135569e00fe25757e20510abaaa8395bb8 100644 (file)
@@ -197,7 +197,7 @@ extra_case (in_abfd, link_info, link_order, reloc, data, src_ptr, dst_ptr)
        {
          bfd_vma dst = bfd_coff_reloc16_get_value (reloc, link_info,
                                                    input_section);
-         /* Adresses are 23 bit, and the layout of those in a 32-bit
+         /* Addresses are 23 bit, and the layout of those in a 32-bit
             value is as follows:
               1AAAAAAA xxxxxxxx AAAAAAAA AAAAAAAA
             (A - address bits,  x - ignore).  */
index 895f96bf750f92c308522affdf1b6846e2527913..0d7ab4f3da0919065a70739182e6e0ea7e6e5f5e 100644 (file)
@@ -1791,7 +1791,7 @@ xcoff64_rtype2howto (relent, internal)
   /* Default howto layout works most of the time */
   relent->howto = &xcoff64_howto_table[internal->r_type];
 
-  /* Special case some 16 bit reoloc */
+  /* Special case some 16 bit reloc */
   if (15 == (internal->r_size & 0x3f))
     {
       if (R_BA == internal->r_type)
index 924bb344306f983384501d5a34c7b205abc5869b..6acdd3978b9f1911b7a1ac49d2fb1994a2478f7d 100644 (file)
@@ -1572,7 +1572,7 @@ coff_new_section_hook (abfd, section)
     return FALSE;
 
   /* We don't need to set up n_name, n_value, or n_scnum in the native
-     symbol information, since they'll be overriden by the BFD symbol
+     symbol information, since they'll be overridden by the BFD symbol
      anyhow.  However, we do need to set the type and storage class,
      in case this symbol winds up getting written out.  The value 0
      for n_numaux is already correct.  */
@@ -4681,7 +4681,7 @@ coff_slurp_symbol_table (abfd)
 #endif
            case C_REGPARM:     /* Register parameter.  */
            case C_REG:         /* register variable.  */
-              /* C_AUTOARG conflictes with TI COFF C_UEXT.  */
+              /* C_AUTOARG conflicts with TI COFF C_UEXT.  */
 #if !defined (TIC80COFF) && !defined (TICOFF)
 #ifdef C_AUTOARG
            case C_AUTOARG:     /* 960-specific storage class.  */
index 91a382288d62c6eac5dc0b44d9ce9e05a06a5ab4..4ad566cc22ed3ef6cb0ea0fcacde1e9168fc1d14 100644 (file)
@@ -2565,7 +2565,7 @@ _bfd_coff_write_global_sym (struct coff_link_hash_entry *h, void *data)
       isym.n_sclass = C_STAT;
     }
 
/* When a weak symbol is not overriden by a strong one,
      turn it into an external symbol when not building a
      shared or relocatable object.  */
   if (! finfo->info->shared
index 7b1dde98221fb7cd471954fb9526c63654668cef..c593fc38537175a77dc90ed1f09639ebcddf84b2 100644 (file)
@@ -39,7 +39,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #define NN(index) (&arch_info_struct[index])
 
-/* These exist only so that we can resonably disassemble PALcode.  */
+/* These exist only so that we can reasonably disassemble PALcode.  */
 static const bfd_arch_info_type arch_info_struct[] =
 {
   N (64, 64, bfd_mach_alpha_ev4, "alpha:ev4", FALSE, NN(1)),
index 9ef527cb94360058da7f3a79e31fc43c6342c991..17889f3b4726dc5b0c74634447811762cbf8ec81 100644 (file)
@@ -155,7 +155,7 @@ const bfd_arch_info_type bfd_arm_arch =
 
 /* Support functions used by both the COFF and ELF versions of the ARM port.  */
 
-/* Handle the mergeing of the 'machine' settings of input file IBFD
+/* Handle the merging of the 'machine' settings of input file IBFD
    and an output file OBFD.  These values actually represent the
    different possible ARM architecture variants.
    Returns TRUE if they were merged successfully or FALSE otherwise.  */
@@ -172,7 +172,7 @@ bfd_arm_merge_machines (ibfd, obfd)
   if (out == bfd_mach_arm_unknown)
     bfd_set_arch_mach (obfd, bfd_arch_arm, in);
 
/* If the input architecure is unknown,
      then so must be the output architecture.  */
   else if (in == bfd_mach_arm_unknown)
     /* FIXME: We ought to have some way to
@@ -184,7 +184,7 @@ bfd_arm_merge_machines (ibfd, obfd)
     ;
 
   /* Otherwise the general principle that a earlier architecture can be
-     linked with a later architecure to produce a binary that will execute
+     linked with a later architecture to produce a binary that will execute
      on the later architecture.
 
      We fail however if we attempt to link a Cirrus EP9312 binary with an
index aab155933237dcdfbb275f68d273351711601e0a..39e5b23937be1e1b07936c4240e1377e22228614 100644 (file)
@@ -194,7 +194,7 @@ do_ns32k_reloc (abfd, reloc_entry, symbol, data, input_section, output_bfd,
   if (reloc_entry->address > input_section->_cooked_size)
     return bfd_reloc_outofrange;
 
-  /* Work out which section the relocation is targetted at and the
+  /* Work out which section the relocation is targeted at and the
      initial relocation command value.  */
 
   /* Get symbol value.  (Common symbols are special.)  */
@@ -678,7 +678,7 @@ _bfd_do_ns32k_reloc_contents (howto, input_bfd, relocation, location,
 
          /* For the signed case we use ADD, rather than SIGNED_ADD,
             to avoid warnings from SVR4 cc.  This is OK since we
-            explictly handle the sign bits.  */
+            explicitly handle the sign bits.  */
          if (signed_add >= 0)
            signed_check += add >> howto->bitpos;
          else
index 49422b2d27ea8c1d229feb41db3e6ce256d8703a..68b3660e24835e593688961356f17958698d6714 100644 (file)
@@ -1530,7 +1530,7 @@ scan_unit_for_functions (unit)
 
 /* Parse a DWARF2 compilation unit starting at INFO_PTR.  This
    includes the compilation unit header that proceeds the DIE's, but
-   does not include the length field that preceeds each compilation
+   does not include the length field that precedes each compilation
    unit header.  END_PTR points one past the end of this comp unit.
    OFFSET_SIZE is the size of DWARF2 offsets (either 4 or 8 bytes).
 
@@ -2565,7 +2565,7 @@ _bfd_coff_write_global_sym (struct coff_link_hash_entry *h, void *data)
     }
 
-  /* When a weak symbol is not overriden by a strong one,
+  /* When a weak symbol is not overridden by a strong one,
      turn it into an external symbol when not building a
      shared or relocatable object.  */
@@ -172,7 +172,7 @@ bfd_arm_merge_machines (ibfd, obfd)
     bfd_set_arch_mach (obfd, bfd_arch_arm, in);
 
-  /* If the input architecure is unknown,
+  /* If the input architecture is unknown,
      then so must be the output architecture.  */
   else if (in == bfd_mach_arm_unknown)
This page took 0.036532 seconds and 4 git commands to generate.